package com.ruoyi.model.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.model.mapper.AppExaminationInstructionsMapper;
import com.ruoyi.model.domain.AppExaminationInstructions;
import com.ruoyi.model.service.IAppExaminationInstructionsService;

/**
 * 考核说明配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@Service
public class AppExaminationInstructionsServiceImpl implements IAppExaminationInstructionsService 
{
    @Autowired
    private AppExaminationInstructionsMapper appExaminationInstructionsMapper;

    /**
     * 查询考核说明配置
     * 
     * @param examinationInstructionsId 考核说明配置主键
     * @return 考核说明配置
     */
    @Override
    public AppExaminationInstructions selectAppExaminationInstructionsByExaminationInstructionsId(Long examinationInstructionsId)
    {
        return appExaminationInstructionsMapper.selectAppExaminationInstructionsByExaminationInstructionsId(examinationInstructionsId);
    }

    /**
     * 查询考核说明配置列表
     * 
     * @param appExaminationInstructions 考核说明配置
     * @return 考核说明配置
     */
    @Override
    public List<AppExaminationInstructions> selectAppExaminationInstructionsList(AppExaminationInstructions appExaminationInstructions)
    {
        return appExaminationInstructionsMapper.selectAppExaminationInstructionsList(appExaminationInstructions);
    }

    /**
     * 新增考核说明配置
     * 
     * @param appExaminationInstructions 考核说明配置
     * @return 结果
     */
    @Override
    public int insertAppExaminationInstructions(AppExaminationInstructions appExaminationInstructions)
    {
        appExaminationInstructions.setCreateTime(DateUtils.getNowDate());
        return appExaminationInstructionsMapper.insertAppExaminationInstructions(appExaminationInstructions);
    }

    /**
     * 修改考核说明配置
     * 
     * @param appExaminationInstructions 考核说明配置
     * @return 结果
     */
    @Override
    public int updateAppExaminationInstructions(AppExaminationInstructions appExaminationInstructions)
    {
        appExaminationInstructions.setUpdateTime(DateUtils.getNowDate());
        return appExaminationInstructionsMapper.updateAppExaminationInstructions(appExaminationInstructions);
    }

    /**
     * 批量删除考核说明配置
     * 
     * @param examinationInstructionsIds 需要删除的考核说明配置主键
     * @return 结果
     */
    @Override
    public int deleteAppExaminationInstructionsByExaminationInstructionsIds(Long[] examinationInstructionsIds)
    {
        return appExaminationInstructionsMapper.deleteAppExaminationInstructionsByExaminationInstructionsIds(examinationInstructionsIds);
    }

    /**
     * 删除考核说明配置信息
     * 
     * @param examinationInstructionsId 考核说明配置主键
     * @return 结果
     */
    @Override
    public int deleteAppExaminationInstructionsByExaminationInstructionsId(Long examinationInstructionsId)
    {
        return appExaminationInstructionsMapper.deleteAppExaminationInstructionsByExaminationInstructionsId(examinationInstructionsId);
    }

    /**
     * 查询考核说明配置列表
     *
     * @return 考核说明配置集合
     */
    @Override
    public List<AppExaminationInstructions> getAppExaminationInstructionsList() {
        return appExaminationInstructionsMapper.getAppExaminationInstructionsList();
    }
}
